@@ -69,6 +69,10 @@ class nokia extends platform {
         return (array) $data->data;
     }
 
+    public function retireCustomer(){
+    }
+
+    public function getDataSession(){}
 
     public function moveSimCustomer($customer){
         $data = $this->api->PUT->devices->{'_'.$this->iccid}(['customer' => $customer]);
